package com.phm.manage.mapper;

import com.phm.manage.domain.LifePartConfig;

import java.util.List;

/**
 * 寿命件配置库信息Mapper接口
 *
 * @author phm
 * @date 2023-08-23
 */
public interface LifePartConfigMapper {
    /**
     * 查询寿命件配置库信息
     *
     * @param id 寿命件配置库信息主键
     * @return 寿命件配置库信息
     */
    public LifePartConfig selectLifePartConfigById(Long id);

    /**
     * 查询寿命件配置库信息列表
     *
     * @param lifePartConfig 寿命件配置库信息
     * @return 寿命件配置库信息集合
     */
    public List<LifePartConfig> selectLifePartConfigList(LifePartConfig lifePartConfig);

    /**
     * 新增寿命件配置库信息
     *
     * @param lifePartConfig 寿命件配置库信息
     * @return 结果
     */
    public int insertLifePartConfig(LifePartConfig lifePartConfig);

    /**
     * 修改寿命件配置库信息
     *
     * @param lifePartConfig 寿命件配置库信息
     * @return 结果
     */
    public int updateLifePartConfig(LifePartConfig lifePartConfig);

    /**
     * 删除寿命件配置库信息
     *
     * @param id 寿命件配置库信息主键
     * @return 结果
     */
    public int deleteLifePartConfigById(Long id);

    /**
     * 批量删除寿命件配置库信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLifePartConfigByIds(Long[] ids);
}
